//
//  TaulaResultatsViewController.m
//  OnTrobarMenus
//
//  Created by Santiago Herrero Blanco on 15/05/13.
//  Copyright (c) 2013 Santiago Herrero Blanco. All rights reserved.
//

#import "TaulaResultatsViewController.h"
#import "DetallRestaurantViewController.h"
#import "AppDelegate.h"
#import <sqlite3.h>

@interface TaulaResultatsViewController (){
    NSMutableArray *restaurants; 
}

@end

@implementation TaulaResultatsViewController

@synthesize sqlRebut; 

- (id)initWithStyle:(UITableViewStyle)style
{
    self = [super initWithStyle:style];
    if (self) {
        // Custom initialization
    }
    return self;
}


//En iniciar la vista, executa el mètode carregarRestaurants
- (void)viewDidLoad
{
    [super viewDidLoad];
    
    restaurants = [[NSMutableArray alloc] init];
    
    [self carregarRestaurants];

}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark - Table view data source


//S'indica que la taula es desitribueix en una única secció
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    // Return the number of sections.
    return 1;
}

//S'indica que la taula tindrà el mateix nombre de fileres com camps tingui la NSMutableArray restaurants
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    // Return the number of rows in the section.
    return [restaurants count];
}


//Es carreguen els valors de cada registre de restaurants a cada cel·la
- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"cell";
    
    NSDictionary *dic = [restaurants objectAtIndex:indexPath.row];
    
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    
    //S'utilitza un tipus de cella predeterminat
    if (cell == nil) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:CellIdentifier];
    }
    
    //En el centre de la cel·la s'ubica el nom del restaurant
    cell.textLabel.text = [dic objectForKey:@"nom"];
    
    
    
    //S'assigna el nom de la imatge a utilitzar per al restaurant, en funció del tipus de requeriment que tingui el restaurant. 
    NSString *nomImaReq;
    
    if ( [[dic objectForKey:@"requeriments"] integerValue]  == 1) {
        nomImaReq = @"gluten-100.png";
    }
    else if ( [[dic objectForKey:@"requeriments"] integerValue] == 2) {
        nomImaReq=@"lactosa-100.png";
    }
    else {
        nomImaReq=@"logo-v2-57.png"; 
    }
    
    UIImage *imaReq = [UIImage imageNamed:nomImaReq];
    cell.imageView.image = imaReq;
    
    // Configure the cell...
    
    return cell;
}

//El mètode accedeix a la taula de la base de dades i desa en el NSMutableArray els registres corresponents als de la taula 
- (void) carregarRestaurants {
    
    AppDelegate *appDelegate = (AppDelegate *)[[UIApplication sharedApplication] delegate];
    
    sqlite3 *database;
    sqlite3_stmt *sentencia;
    
    if (sqlite3_open ([appDelegate.dataBasePath UTF8String], &database) == SQLITE_OK){
        NSString *sentenciaSQL = sqlRebut; 
        if (sqlite3_prepare_v2(database, [sentenciaSQL UTF8String], -1, &sentencia, NULL) == SQLITE_OK) {
            while (sqlite3_step(sentencia) ==SQLITE_ROW) {
                NSMutableDictionary *dic = [[NSMutableDictionary alloc]init];
                NSString *idRest = [NSString stringWithUTF8String:(char *)sqlite3_column_text(sentencia, 0)];
                [dic setValue:idRest forKey:@"idRest"];
                NSString *nom = [NSString stringWithUTF8String:(char *)sqlite3_column_text(sentencia, 1)];
                [dic setValue:nom forKey:@"nom"];
                NSString *adreca = [NSString stringWithUTF8String:(char *)sqlite3_column_text(sentencia, 2)];
                [dic setValue:adreca forKey:@"adreca"];
                char* mail = (char *)sqlite3_column_text(sentencia, 3);
                NSString *email = mail == NULL ? @"Dada no disponible" : [[NSString  alloc] initWithUTF8String:mail];
                [dic setValue:email forKey:@"email"]; 
                char* www = (char *)sqlite3_column_text(sentencia, 4);
                NSString *web = www == NULL ? @"Dada no disponible" : [[NSString  alloc] initWithUTF8String:www];
                [dic setValue:web forKey:@"web"];
                char* numTelf = (char *)sqlite3_column_text(sentencia, 5);
                NSString *telf = numTelf == NULL ? @"Dada no disponible" : [[NSString  alloc] initWithUTF8String:numTelf];
                [dic setValue:telf forKey:@"telf"]; 
                NSString *localitat = [NSString stringWithUTF8String:(char *)sqlite3_column_text(sentencia, 6)];
                [dic setValue:localitat forKey:@"localitat"];
                NSString *req = [NSString stringWithUTF8String:(char *)sqlite3_column_text(sentencia, 7)];
                [dic setValue:req forKey:@"requeriments"];
                NSString *rang = [NSString stringWithUTF8String:(char *)sqlite3_column_text(sentencia, 8)];
                [dic setValue:rang forKey:@"rang"];
                NSString *latRest = [NSString stringWithUTF8String:(char *)sqlite3_column_text(sentencia, 9)];
                [dic setValue:latRest forKey:@"latRest"];
                NSString *longRest = [NSString stringWithUTF8String:(char *)sqlite3_column_text(sentencia, 10)];
                [dic setValue:longRest forKey:@"longRest"];
                [restaurants addObject:dic];
            }
        }
        sqlite3_finalize(sentencia);
    }
    sqlite3_close(database);
    [restaurants count];


    //Si al final de l'execució el NSMutableArray està buit, mostra un missatge indicant que no s'han trobat restaurants. 
    
    if ([restaurants count] == 0) {
        UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Ho sentim" message:@"No s'han trobat restaurants amb aquests criteris de recerca" delegate:nil cancelButtonTitle:@"Acceptar" otherButtonTitles:nil, nil];
        [alert show];
    }
}


//Mètode que serveix per preparar les transicions a altres vistes en què s'han de traspasar dades 
- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender
{

    if ([[segue identifier] isEqualToString:@"segDetRest"])
    {
        //Passa a la vista de el detall de l'ítem seleccionat. 
        DetallRestaurantViewController *detall = [segue destinationViewController];
        NSIndexPath *indexPath = [self.tableView indexPathForSelectedRow];
        [detall setDetailItem:[restaurants objectAtIndex:indexPath.row]];
    }
}

@end
